<?php

use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateUsersTable extends Migration {

	/**
	 * Run the migrations.
	 *
	 * @return void
	 */
	public function up()
	{
		//
		Schema::create('users', function(Blueprint $table)
		{
			$table->increments('id');
			$table->string('introduce_id');
			$table->integer('parent_id')->unsigned()->nullable();
			$table->enum('login_type', array('NINETEN','Facebook'));
			$table->string('email')->unique();
			$table->string('account')->unique();
			$table->string('password');
			$table->string('register_time');
			$table->string('last_login_time');
			$table->enum('status', array('正常','停權'));
			$table->enum('authority', array('一般','特殊'));
			$table->string('name');
			$table->string('gender');
			$table->date('birthday');
			$table->string('phone', 20);
			$table->string('address1', 255);
			$table->string('address2', 255);
			$table->string('address3', 255);
			$table->boolean('is_available')->default(true);
			$table->string('identification')->unique();
			$table->enum('level', array('種子帳戶','一般帳戶'));
			$table->timestamps();
			
			$table->foreign('parent_id')->references('id')->on('users')->onDelete('set null');
		});

		Schema::create('records', function(Blueprint $table)
		{
			$table->increments('id');
			$table->integer('user_id')->unsigned();
			$table->integer('month_1')->default(0);
			$table->integer('month_2')->default(0);
			$table->integer('month_3')->default(0);
			$table->integer('month_4')->default(0);
			$table->integer('month_5')->default(0);
			$table->integer('month_6')->default(0);
			$table->integer('month_7')->default(0);
			$table->integer('month_8')->default(0);
			$table->integer('month_9')->default(0);
			$table->integer('month_10')->default(0);
			$table->integer('month_11')->default(0);
			$table->integer('month_12')->default(0);
			$table->integer('bonus_money')->default(0);
			$table->integer('bonus_used')->default(0);
			$table->integer('money_used')->default(0);
			
			$table->foreign('user_id')->references('id')->on('users')->onDelete('cascade');
		});
		//
	}

	/**
	 * Reverse the migrations.
	 *
	 * @return void
	 */
	public function down()
	{
	
		DB::statement('SET FOREIGN_KEY_CHECKS = 0');
		Schema::dropIfExists('users');
		Schema::dropIfExists('records');
		DB::statement('SET FOREIGN_KEY_CHECKS = 1');
	}

}
