<?php

use Illuminate\Database\Schema\Blueprint;
use Illuminate\Database\Migrations\Migration;

class CreateProductsTable extends Migration {

	/**
	 * Run the migrations.
	 *
	 * @return void
	 */
	public function up()
	{

		Schema::create('products_categories', function(Blueprint $table)
		{
			$table->increments('id');
			$table->string('name');
			$table->timestamps();
		});
        
		Schema::create('products', function(Blueprint $table)
		{
			$table->increments('id');
			$table->string('product_code')->unique();
			$table->integer('category_id')->unsigned()->nullable();
			$table->integer('bonus_category_id')->unsigned()->nullable();
			$table->string('title');
			$table->integer('price');
			$table->integer('selling_price');
			$table->text('description');
			$table->text('image_json');
			$table->string('img_path');
			$table->string("format");
			$table->text("introduction");
			$table->enum("is_available", array('上架','下架','隱藏'));
			$table->integer("available_amount");
			$table->integer("stock_amount");
			$table->integer("soldout_amount");
			$table->integer("preorder_amount");
			$table->integer("stock_threshold");
			$table->string('video_url');
			$table->enum('type', array('一般商品','集量商品','限時商品'));
			$table->string('product_status');
			$table->string('special_case');
			$table->integer("deal_status");
			$table->integer("deal_baseline");
			$table->timestamp("open_date");
			$table->timestamp('close_date');
			$table->timestamps();

			$table->foreign('category_id')->references('id')->on('products_categories')->onDelete('cascade');
			$table->foreign('bonus_category_id')->references('id')->on('bonuses_categories')->onDelete('set null');
		});
        
        Schema::create('products_detail', function(Blueprint $table)
		{
			$table->increments('id');
			$table->integer('product_id')->unsigned();
			$table->string('img_title');
			$table->string('image');
			$table->string('img_description');
			$table->timestamps();
            
            $table->foreign('product_id')->references('id')->on('products')->onDelete('cascade');
		});

		Schema::create('products_activities', function(Blueprint $table)
		{
			$table->increments('id');
			$table->string('product_code')->unique();
			$table->integer('product_id')->unsigned();
			$table->integer('status');
			$table->string('title');
			$table->string('format');
			$table->integer('sequence');
			$table->integer('activities_num');
			$table->integer('price');
			$table->integer('selling_price');
			$table->integer('available_amount');
			$table->integer('stock_amount');
			$table->enum("is_available", array('上架','下架'));
			$table->timestamp('starting_time');
			$table->timestamp('ended_time');
			$table->integer('deal_lowerbound');
			$table->integer('deal_upperbound');
			$table->timestamps();

            $table->foreign('product_id')->references('id')->on('products')->onDelete('cascade');
		});
	}

	/**
	 * Reverse the migrations.
	 *
	 * @return void
	 */
	public function down()
	{
		DB::statement('SET FOREIGN_KEY_CHECKS = 0');
		Schema::dropIfExists('products_categories');
		Schema::dropIfExists('products_detail');
		Schema::dropIfExists('products_activities');
		Schema::dropIfExists('products');
		Schema::dropIfExists('records');
		Schema::dropIfExists('users');
		DB::statement('SET FOREIGN_KEY_CHECKS = 1');
		//
	}

}
