<?php

class DatabaseSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        Eloquent::unguard();

        DB::table('bonuses')->delete();
        DB::table('bonuses_categories')->delete();
        DB::table('transactions')->delete();
        DB::table('products_detail')->delete();

        $this->call('UserTableSeeder');
        $this->call('AdministratorTableSeeder');
        $this->call('TransactionsTableSeeder');
        $this->call('BonusesTableSeeder');
        $this->call('ProductCategoryTableSeeder');
        $this->call('ProductTableSeeder');

        $this->call('RecordsTableSeeder');
        $this->call('OperatorLogTableSeeder');
    }
}

class OperatorLogTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        DB::table('operator_log')->delete();
        $time = new DateTime;
        
        $admins = Administrator::all();

        for($i = 0; $i < count($admins); $i++) {
            $operators = array(
                'admin_id' => $admins[$i]->id,
                'operator' => '刪除 商品一',
                'created_at' => $time,
                'updated_at' => $time
            );
            DB::table('operator_log')->insert($operators);
        }
    }
}
class TransactionsTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $time = new DateTime;


        $users = User::all();

        for($i = 0; $i < count($users); $i++) {
            $transaction = array(
                'user_id' => $users[$i]->id,
                'money' => 100,
                'bonus_money' => 50,
                'status' => '已出貨',
                'address' => '台南市好地方',
                'mail' => 'bee040811@gmail.com',
                'products_json' => '[{"id":"3","num":"5"}]',
                'date' => $time,
                'created_at' => $time,
                'updated_at' => $time
            );
            DB::table('transactions')->insert($transaction);
        }
    }
}

class BonusesTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     * w
     */
    public function run()
    {
        $time = new DateTime;


        $transactions = Transaction::all();

        for($i = 0; $i < count($transactions); $i++) {
            $bonus[0] = array(
                'transaction_id' => $transactions[$i]->id,
                'user_id' => $transactions[$i]->user_id,
                'bonus' => 50,
                'description' => '成功下定',
                'type' => '紅利使用',
                'date' => $time,
                'created_at' => $time,
                'updated_at' => $time
            );
            $bonus[1] = array(
                'transaction_id' => $transactions[$i]->id,
                'user_id' => $transactions[$i]->user_id,
                'bonus' => 30,
                'description' => '成功下定2',
                'type' => '紅利使用',
                'date' => $time,
                'created_at' => $time,
                'updated_at' => $time
            );
            $bonus[2] = array(
                'transaction_id' => $transactions[$i]->id,
                'user_id' => $transactions[$i]->user_id,
                'bonus' => 100,
                'description' => '成功兌現',
                'type' => '兌現',
                'date' => $time,
                'created_at' => $time,
                'updated_at' => $time
            );
            $bonus[3] = array(
                'transaction_id' => $transactions[$i]->id,
                'user_id' => $transactions[$i]->user_id,
                'bonus' => 500,
                'description' => '成功兌現',
                'type' => '兌現',
                'date' => $time,
                'created_at' => $time,
                'updated_at' => $time
            );
            DB::table('bonuses')->insert($bonus);
        }

        DB::table('bonuses_categories')->insert(array(
            array(
                'category'=>'A方案',
                'code'=>'A9',
                'value'=>'0.2',
                'retail_value'=>'0.4',
                'introduction_value'=>'0.3',
                'bonus_value'=>'0.4',
                'created_at' => $time,
                'updated_at' => $time
            ),
            array(
                'category'=>'B方案',
                'code'=>'B9',
                'value'=>'0.3',
                'retail_value'=>'0.4',
                'introduction_value'=>'0.3',
                'bonus_value'=>'0.4',
                'created_at' => $time,
                'updated_at' => $time
            ),
            array(
                'category'=>'C方案',
                'code'=>'C9',
                'value'=>'0.4',
                'retail_value'=>'0.4',
                'introduction_value'=>'0.3',
                'bonus_value'=>'0.4',
                'created_at' => $time,
                'updated_at' => $time
            ),
        ));
    }
}

class AdministratorTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        $salt = Config::get('Myadmin::admin.salt');
        $time = new DateTime;

        DB::table('administrators')->delete();

        DB::table('administrators')->insert(array(
            array(
                'account'=>'customer',
                'password'=> crypt('architech3388', $salt),
                'username'=>'jack1112',
                'level'=>'客服人員',
                'created_at'=> $time,
                'updated_at'=> $time
            ),
            array(
                'account'=>'employee',
                'password'=> crypt('architech3388', $salt),
                'username'=>'jack0415',
                'level'=>'退換貨人員',
                'created_at'=> $time,
                'updated_at'=> $time
            ),
            array(
                'account'=>'admin',
                'password'=> crypt('architech3388', $salt),
                'username'=>'bee040811',
                'level'=>'最高管理員',
                'created_at'=> $time,
                'updated_at'=> $time
            ),
            array(
                'account'=>'user',
                'password'=> crypt('architech3388', $salt),
                'username'=>'bee040811',
                'level'=>'客服人員',
                'created_at'=> $time,
                'updated_at'=> $time
            )
        ));
    }
}

class ProductCategoryTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {

        DB::table('products_categories')->delete();

        DB::table('products_categories')->insert(array(
            array(
                'name'=>'文具'),
            array(
                'name'=>'3C'),
			array(
				'name'=>'配飾'),
			array(
				'name'=>'傢飾'),
			array(
				'name'=>'日常'),
			array(
				'name'=>'美妝'),
			array(
				'name'=>'燈飾'),
			array(
				'name'=>'餐廚'),
			array(
				'name'=>'戶外'),
			array(
				'name'=>'集量商品'),
			array(
				'name'=>'限時商品')

            ));
    }
}

class ProductTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {

        DB::table('products')->delete();

        $categories = ProductCategories::all();
        $bonus_category = BonusesCategories::all();
        $date = new DateTime;

        for($i = 0; $i < count($categories)-2; $i++) {
			$product = array(
					'product_code'=> $this->generateRandomString(5),
					'category_id'=> $categories[$i]->id,
					'bonus_category_id'=> $bonus_category[0]->id,
					'title'=>'Net-' . $this->generateRandomString(5),
					'price'=>'30',
					'selling_price'=>'50',
					'description'=>'描述',
					'img_path'=>'',
					'format'=>'yellow-S',
					'introduction'=>'介紹',
					'is_available'=>'上架',
					'video_url'=>'https://www.youtube.com/watch?v=ojUUBoddvOo&index=5&list=FLU6u0txj1Z_9hiKxqowPpKA',
					'available_amount'=>'1',
					'stock_amount'=>'1',
					'stock_threshold'=>'5',
					'type'=>'一般商品',
					'created_at'=>$date,
					'updated_at'=>$date
			);
			if($i%4 == 0){
				$products = array(
					'product_code'=> $this->generateRandomString(5),
					'category_id'=> $categories[9]->id,
					'bonus_category_id'=> $bonus_category[0]->id,
					'title'=>'Net-' . $this->generateRandomString(5),
					'price'=>'30',
					'selling_price'=>'50',
					'description'=>'描述',
					'img_path'=>'',
					'format'=>'yellow-M',
					'introduction'=>'介紹',
					'is_available'=>'上架',
					'video_url'=>'https://www.youtube.com/watch?v=ojUUBoddvOo&index=5&list=FLU6u0txj1Z_9hiKxqowPpKA',
					'available_amount'=>'1',
					'stock_amount'=>'1',
					'stock_threshold'=>'5',
					'type'=>'集量商品',
					'deal_baseline'=>'50',
					'close_date'=>$date,
					'created_at'=>$date,
					'updated_at'=>$date
				);
	            DB::table('products')->insert(array(
    	            $products
        	    ));
			}
			else if($i%3 == 0){
				$products = array(
					'product_code'=> $this->generateRandomString(5),
					'category_id'=> $categories[10]->id,
					'bonus_category_id'=> $bonus_category[0]->id,
					'title'=>'Net-' . $this->generateRandomString(5),
					'price'=>'20',
					'selling_price'=>'40',
					'description'=>'描述',
					'img_path'=>'',
					'format'=>'yellow-XL',
					'introduction'=>'介紹',
					'is_available'=>'上架',
					'video_url'=>'https://www.youtube.com/watch?v=ojUUBoddvOo&index=5&list=FLU6u0txj1Z_9hiKxqowPpKA',
					'available_amount'=>'1',
					'stock_amount'=>'1',
					'stock_threshold'=>'5',
					'type'=>'限時商品',
					'close_date'=>$date,
					'created_at'=>$date,
					'updated_at'=>$date
				);
				DB::table('products')->insert(array(
					$products
				));
			}
            DB::table('products')->insert(array(
                $product
            ));
        }
        
        $products = Product::all();

        DB::table('products_detail')->insert(array(
            array(
                'product_id' => $products[0]->id,
                'img_title' => 'test123',
                'img_description' => 'good'
            )
        ));


		$activity[0] = array(
				'product_id'=>$products[0]->id,
				'product_code' => 'ASFW89',
				'title' => '簽名筆',
				'format' => '紅色',
				'sequence' => '1',
				'activities_num' => '1',
				'price' => '550',
				'selling_price' => '500',
				'is_available' => '上架',
				'starting_time' => $date,
				'ended_time' => $date,
				'deal_lowerbound' => '500',
				'deal_upperbound' => '900',
				'created_at' => $date,
				'updated_at' => $date
		);
		DB::table('products_activities')->insert($activity[0]);
		
		$activity[1] = array(
				'product_id'=>$products[4]->id,
				'product_code' => 'DSAF3424'.$this->generateRandomNum(4),
				'title' => '奇異筆',
				'format' => '綠色',
				'sequence' => '1',
				'activities_num' => '1',
				'price' => '900',
				'selling_price' => '500',
				'available_amount' => '500',
				'stock_amount' => '800',
				'is_available' => '上架',
				'starting_time' => $date,
				'ended_time' => $date,
				'created_at' => $date,
				'updated_at' => $date
		);
		DB::table('products_activities')->insert($activity[1]);

    }

    public function generateRandomString($length = 10) {
        $characters = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }

    public function generateRandomNum($length = 10) {
        $characters = '0123456789';
        $charactersLength = strlen($characters);
        $randomString = '';
        for ($i = 0; $i < $length; $i++) {
            $randomString .= $characters[rand(0, $charactersLength - 1)];
        }
        return $randomString;
    }
}

class RecordsTableSeeder extends Seeder {

    /**
     * Run the database seeds.
     *
     * @return void
     */
    public function run()
    {
        DB::table('records')->delete();

        $users = User::all();
        for($i = 0; $i < count($users); $i++) {
            $bonus = Bonustable::where("user_id", $users[$i]->id)
                ->where("type", "紅利使用")
                ->sum('bonus');
            $money = Bonustable::where("user_id", $users[$i]->id)
                ->where("type", "兌現")
                ->sum('bonus');

            $record = array(
                'user_id'=> $users[$i]->id,
                'month_1'=>'100',
                'month_2'=>'200',
                'month_3'=>'200',
                'bonus_money'=> '30',
                'bonus_used'=> $bonus,
                'money_used'=> $money);
            DB::table('records')->insert(array(
                $record
            ));
        }
    }
}
