<?php

class MyadminArticleController extends \BaseController {

    protected $layout = 'Myadmin::layout.basic';

    // self defined members
    protected $_CONST;
    protected $articleModelInstance;
    protected $articleClassModelInstance;


    public function __construct()
    {
        $routeName = Route::currentRouteName();
        $routeName = substr($routeName, 0, strrpos($routeName, '.'));
        $routeAction = Route::currentRouteAction();
        $routeAction = substr($routeAction, 0, strrpos($routeAction, '@'));

        $this->_CONST = array();
        $this->_CONST["CONTROLLER_ROUTE"] = $routeName;
        $this->_CONST["CONTROLLER_ACTION"] = $routeAction;
        $this->_CONST["CLASS_CONTROLLER"] = $this->getClassController(); // interface function
        $this->_CONST["LANG_DEST"] = $this->getLangDest(); // interface function

        $this->articleModelInstance = $this->getArticleInstance();
        $this->articleClassModelInstance = $this->getArticleClassInstance();
    
    }
    /**
     * Display a listing of the resource.
     *
     * @return Response
     */
    public function index()
    {
        $a = $this->getArticleInstance();
        $categories = array();
        $categories[0] = "總覽";
        foreach ($this->articleClassModelInstance->all() as $category ) {
            $categories[$category->id] = $category->title;
        }
        $this->layout->content = View::make('article-system::article.index')
            ->withFronturl($this->getFrontUrl())
            ->with('_CONST', $this->_CONST)
            ->withCategories($categories)
            ->withArticles($this->articleModelInstance->all());
    }


    /**
     * Show the form for creating a new resource.
     *
     * @return Response
     */
    public function create()
    {
        $option = array();
        foreach ($this->articleClassModelInstance->all() as $category) {
            $option[$category->id] = $category->title;
        }
        if (Input::has("category")) {
            $default = Input::get("category");
        }else{
            $default = 1;
        }
        $this->layout->content = View::make('article-system::article.create')
            ->with('_CONST', $this->_CONST)
            ->withOption($option)
            ->withDefault($default);
    }


    /**
     * Store a newly created resource in storage.
     *
     * @return Response
     */
    public function store()
    {
        $userInput = Input::all();
        $article = $this->articleModelInstance;
        $article->title = $userInput['title'];
        $article->category_id = $userInput['category_id'];
        $article->origin_content = $userInput['origin_content'];
        $article->content = strip_tags($userInput['origin_content']);
        $article->profolio_path = extract_first_img($userInput['origin_content']);
        $article->save();
        return Redirect::route($this->_CONST["CONTROLLER_ROUTE"].'.index');
    }


    /**
     * Display the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function show($id)
    {
        $a = $this->getArticleInstance();
        $categories[0] = "總覽";
        foreach ($this->articleClassModelInstance->all() as $category ) {
            $categories[$category->id] = $category->title;
        }
            
        $this->layout->content = View::make('article-system::article.show')
            ->withFronturl($this->getFrontUrl())
            ->with('_CONST', $this->_CONST)
            ->withCid($id)
            ->withCategories($categories)
            ->withArticles($this->articleClassModelInstance->findOrFail($id)->articles);
    }


    /**
     * Show the form for editing the specified resource.
     *
     * @param  int  $id
     * @return Response
     */
    public function edit($id)
    {
        $article = $this->articleModelInstance->findOrFail($id);
        foreach ($this->articleClassModelInstance->all() as $category) {
            $option[$category->id] = $category->title;
        }
        $this->layout->content = View::make('article-system::article.edit')
            ->with('_CONST', $this->_CONST)
            ->withOption($option)
            ->withArticle($article);
    }


    /**
     * Update the specified resource in storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function update($id)
    {
        $userInput = Input::all();
        $article = $this->articleModelInstance->findOrFail($id);
        $article->title = $userInput['title'];
        $article->category_id = $userInput['category_id'];
        $article->origin_content = $userInput['origin_content'];
        $article->content = strip_tags($userInput['origin_content']);
        $article->profolio_path = extract_first_img($userInput['origin_content']);
        $article->save();
        return Redirect::route($this->_CONST["CONTROLLER_ROUTE"].'.index');
    }


    /**
     * Remove the specified resource from storage.
     *
     * @param  int  $id
     * @return Response
     */
    public function destroy($id)
    {
        $article = $this->articleModelInstance->findOrFail($id);
        $article->delete();
        return Redirect::route($this->_CONST["CONTROLLER_ROUTE"].'.index');
    }

    public function getLangDest()
    {
        return "article-system::view";
    }

    /*
    public function getClassController()
    {
        // rewrite classes controller by extended controller...
    }

    private function getArticleInstance()
    {
        // return an instance of model
    }
    */
}
